# mypy-boto3-mediaconnect<a id="mypy-boto3-mediaconnect"></a>

[![PyPI - mypy-boto3-mediaconnect](https://img.shields.io/pypi/v/mypy-boto3-mediaconnect.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediaconnect)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-mediaconnect.svg?color=blue)](https://pypi.org/project/mypy-boto3-mediaconnect)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-mediaconnect?color=blue)](https://pypistats.org/packages/mypy-boto3-mediaconnect)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.MediaConnect 1.17.89](https://boto3.amazonaws.com/v1/documentation/api/1.17.89/reference/services/mediaconnect.html#MediaConnect)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.15.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-mediaconnect docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediaconnect/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-mediaconnect](#mypy-boto3-mediaconnect)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

## How to install<a id="how-to-install"></a>

Install `boto3-stubs` for `MediaConnect` service.

```bash
python -m pip install boto3-stubs[mediaconnect]
```

## Usage<a id="usage"></a>

### VSCode<a id="vscode"></a>

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[mediaconnect]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconnect]'`

Both type checking and auto-complete should work for `MediaConnect` service. No
explicit type annotations required, write your `boto3` code as usual.

### PyCharm<a id="pycharm"></a>

- Install `boto-stubs[mediaconnect]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconnect]'`

Both type checking and auto-complete should work for `MediaConnect` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs<a id="other-ides"></a>

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy<a id="mypy"></a>

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[mediaconnect]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconnect]'`
- Run `mypy` as usual

Type checking should work for `MediaConnect` service. No explicit type
annotations required, write your `boto3` code as usual.

### pyright<a id="pyright"></a>

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[mediaconnect]` in your environment:
  `python -m pip install 'boto3-stubs[mediaconnect]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `MediaConnect` service. No explicit type
annotations required, write your `boto3` code as usual.

## Explicit type annotations<a id="explicit-type-annotations"></a>

### Client annotations<a id="client-annotations"></a>

`MediaConnectClient` provides annotations for `boto3.client("mediaconnect")`.

```python
import boto3

from mypy_boto3_mediaconnect import MediaConnectClient

client: MediaConnectClient = boto3.client("mediaconnect")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: MediaConnectClient = session.client("mediaconnect")
```

### Paginators annotations<a id="paginators-annotations"></a>

`mypy_boto3_mediaconnect.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_mediaconnect import MediaConnectClient
from mypy_boto3_mediaconnect.paginator import (
    ListEntitlementsPaginator,
    ListFlowsPaginator,
    ListOfferingsPaginator,
    ListReservationsPaginator,
)

client: MediaConnectClient = boto3.client("mediaconnect")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_entitlements_paginator: ListEntitlementsPaginator = client.get_paginator("list_entitlements")
list_flows_paginator: ListFlowsPaginator = client.get_paginator("list_flows")
list_offerings_paginator: ListOfferingsPaginator = client.get_paginator("list_offerings")
list_reservations_paginator: ListReservationsPaginator = client.get_paginator("list_reservations")
```

### Waiters annotations<a id="waiters-annotations"></a>

`mypy_boto3_mediaconnect.waiter` module contains type annotations for all
waiters.

```python
from mypy_boto3_mediaconnect import MediaConnectClient
from mypy_boto3_mediaconnect.waiter import (
    FlowActiveWaiter,
    FlowDeletedWaiter,
    FlowStandbyWaiter,
)

client: MediaConnectClient = boto3.client("mediaconnect")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
flow_active_waiter: FlowActiveWaiter = client.get_waiter("flow_active")
flow_deleted_waiter: FlowDeletedWaiter = client.get_waiter("flow_deleted")
flow_standby_waiter: FlowStandbyWaiter = client.get_waiter("flow_standby")
```

### Literals<a id="literals"></a>

`mypy_boto3_mediaconnect.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_mediaconnect.literals import (
    AlgorithmType,
    ColorimetryType,
    DurationUnitsType,
    EncoderProfileType,
    EncodingNameType,
    EntitlementStatusType,
    FlowActiveWaiterName,
    FlowDeletedWaiterName,
    FlowStandbyWaiterName,
    KeyTypeType,
    ListEntitlementsPaginatorName,
    ListFlowsPaginatorName,
    ListOfferingsPaginatorName,
    ListReservationsPaginatorName,
    MediaStreamTypeType,
    NetworkInterfaceTypeType,
    PriceUnitsType,
    ProtocolType,
    RangeType,
    ReservationStateType,
    ResourceTypeType,
    ScanModeType,
    SourceTypeType,
    StateType,
    StatusType,
    TcsType,
)

def check_value(value: AlgorithmType) -> bool:
    ...
```

### Typed dictionaries<a id="typed-dictionaries"></a>

`mypy_boto3_mediaconnect.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_mediaconnect.type_defs import (
    AddFlowMediaStreamsResponseTypeDef,
    AddFlowOutputsResponseTypeDef,
    AddFlowSourcesResponseTypeDef,
    AddFlowVpcInterfacesResponseTypeDef,
    AddMediaStreamRequestTypeDef,
    AddOutputRequestTypeDef,
    CreateFlowResponseTypeDef,
    DeleteFlowResponseTypeDef,
    DescribeFlowResponseTypeDef,
    DescribeOfferingResponseTypeDef,
    DescribeReservationResponseTypeDef,
    DestinationConfigurationRequestTypeDef,
    DestinationConfigurationTypeDef,
    EncodingParametersRequestTypeDef,
    EncodingParametersTypeDef,
    EncryptionTypeDef,
    EntitlementTypeDef,
    FailoverConfigTypeDef,
    FlowTypeDef,
    FmtpRequestTypeDef,
    FmtpTypeDef,
    GrantEntitlementRequestTypeDef,
    GrantFlowEntitlementsResponseTypeDef,
    InputConfigurationRequestTypeDef,
    InputConfigurationTypeDef,
    InterfaceRequestTypeDef,
    InterfaceTypeDef,
    ListEntitlementsResponseTypeDef,
    ListFlowsResponseTypeDef,
    ListOfferingsResponseTypeDef,
    ListReservationsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListedEntitlementTypeDef,
    ListedFlowTypeDef,
    MediaStreamAttributesRequestTypeDef,
    MediaStreamAttributesTypeDef,
    MediaStreamOutputConfigurationRequestTypeDef,
    MediaStreamOutputConfigurationTypeDef,
    MediaStreamSourceConfigurationRequestTypeDef,
    MediaStreamSourceConfigurationTypeDef,
    MediaStreamTypeDef,
    MessagesTypeDef,
    OfferingTypeDef,
    OutputTypeDef,
    PaginatorConfigTypeDef,
    PurchaseOfferingResponseTypeDef,
    RemoveFlowMediaStreamResponseTypeDef,
    RemoveFlowOutputResponseTypeDef,
    RemoveFlowSourceResponseTypeDef,
    RemoveFlowVpcInterfaceResponseTypeDef,
    ReservationTypeDef,
    ResourceSpecificationTypeDef,
    ResponseMetadataTypeDef,
    RevokeFlowEntitlementResponseTypeDef,
    SetSourceRequestTypeDef,
    SourceTypeDef,
    StartFlowResponseTypeDef,
    StopFlowResponseTypeDef,
    TransportTypeDef,
    UpdateEncryptionTypeDef,
    UpdateFailoverConfigTypeDef,
    UpdateFlowEntitlementResponseTypeDef,
    UpdateFlowMediaStreamResponseTypeDef,
    UpdateFlowOutputResponseTypeDef,
    UpdateFlowResponseTypeDef,
    UpdateFlowSourceResponseTypeDef,
    VpcInterfaceAttachmentTypeDef,
    VpcInterfaceRequestTypeDef,
    VpcInterfaceTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AddFlowMediaStreamsResponseTypeDef:
    return {
      ...
    }
```

## Versioning<a id="versioning"></a>

`mypy-boto3-mediaconnect` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation<a id="documentation"></a>

All type annotations can be found in
[mypy-boto3-mediaconnect docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_mediaconnect/)

## Support and contributing<a id="support-and-contributing"></a>

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
